@@ -908,8 +908,8 @@ class AWS_STS_API STSClient : public Aws::Client::AWSXMLClient, public Aws::Clie
     return SubmitAsync(&STSClient::GetWebIdentityToken, request, handler, context);
   }
 
-  void OverrideEndpoint(const Aws::String& endpoint);
-  std::shared_ptr<STSEndpointProviderBase>& accessEndpointProvider();
+  virtual void OverrideEndpoint(const Aws::String& endpoint);
+  virtual std::shared_ptr<STSEndpointProviderBase>& accessEndpointProvider();
 
  private:
   friend class Aws::Client::ClientWithAsyncTemplateMethods<STSClient>;
